==> ae_kivy_help-0.1.19.tar.gz: ae_kivy_help-0.1.19/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# kivy_help portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_kivy_help/master?logo=python)](
    https://gitlab.com/ae-group/ae_kivy_help)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_kivy_help)](
    https://pypi.org/project/ae-kivy-help/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_kivy_help/coverage.svg)](
    https://ae-group.gitlab.io/ae_kivy_help/coverage/ae_kivy_help_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_kivy_help/mypy.svg)](
    https://ae-group.gitlab.io/ae_kivy_help/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_kivy_help/pylint.svg)](
    https://ae-group.gitlab.io/ae_kivy_help/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_kivy_help)](
    https://pypi.org/project/ae-kivy-help/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_kivy_help)](
    https://pypi.org/project/ae-kivy-help/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_kivy_help)](
    https://pypi.org/project/ae-kivy-help/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_kivy_help)](
    https://pypi.org/project/ae-kivy-help/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_kivy_help)](
    https://libraries.io/pypi/ae-kivy-help)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_kivy_help)](
    https://pypi.org/project/ae-kivy-help/#files)


## installation


Execute the following command for to use the ae.kivy_help module in your
application. It will install ae.kivy_help into your python (virtual) environment:
 
```shell script
pip install ae-kivy-help
```

If you instead want to contribute to this portion then first fork
[the ae_kivy_help repository at GitLab](https://gitlab.com/ae-group/ae_kivy_help "ae.kivy_help code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_kivy_help):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.kivy_help.html#module-ae.kivy_help
"ae_kivy_help documentation").

<!-- Common files version 0.0.60 deployed version 0.1.2 (with 0.0.60)
     to https://gitlab.com/ae-group as ae_kivy_help module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-kivy-help as namespace portion ae-kivy-help.
-->

==> ae_kivy_help-0.2.32.tar.gz: ae_kivy_help-0.2.32/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
-->
# kivy_help portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_kivy_help/master?logo=python)](
    https://gitlab.com/ae-group/ae_kivy_help)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_kivy_help)](
    https://pypi.org/project/ae-kivy-help/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_kivy_help/coverage.svg)](
    https://ae-group.gitlab.io/ae_kivy_help/coverage/ae_kivy_help_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_kivy_help/mypy.svg)](
    https://ae-group.gitlab.io/ae_kivy_help/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_kivy_help/pylint.svg)](
    https://ae-group.gitlab.io/ae_kivy_help/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_kivy_help)](
    https://pypi.org/project/ae-kivy-help/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_kivy_help)](
    https://pypi.org/project/ae-kivy-help/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_kivy_help)](
    https://pypi.org/project/ae-kivy-help/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_kivy_help)](
    https://pypi.org/project/ae-kivy-help/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_kivy_help)](
    https://libraries.io/pypi/ae-kivy-help)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_kivy_help)](
    https://pypi.org/project/ae-kivy-help/#files)


## installation


execute the following command to use the ae.kivy_help sub-package in your
application. it will install ae.kivy_help into your python (virtual) environment:
 
```shell script
pip install ae-kivy-help
```

if you instead want to contribute to this portion then first fork
[the ae_kivy_help repository at GitLab](https://gitlab.com/ae-group/ae_kivy_help "ae.kivy_help code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_kivy_help):

```shell script
pip install -e .[dev]
```

the last command will install this sub-package portion into your virtual environment, along with
the tools you need to develop and run tests or to extend the portion documentation.
to contribute only to the unit tests or to the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

more info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.kivy_help.html#module-ae.kivy_help
"ae_kivy_help documentation").

<!-- common files version 0.2.77 deployed version 0.2.27 (with 0.2.77)
     to https://gitlab.com/ae-group as ae_kivy_help sub-package as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-kivy-help as namespace portion ae-kivy-help.
-->
